from __future__ import unicode_literals

from django.conf.urls import patterns, include, url
from django.conf.urls.static import static
from django.contrib import admin

from demo.views import HomeView, AccessView, LastAccessView, LastModelActionView, CreateModelActionView, \
    UpdateModelActionView, DeleteModelActionView, access_function_based_view, AccessExceptionView, access_decorated_view
from demo.settings import DEBUG, STATIC_URL, STATIC_ROOT
# Uncomment the next two lines to enable the admin:
# from django.contrib import admin

admin.autodiscover()

urlpatterns = patterns('',
    # Examples:
    # url(r'^$', 'demo.views.home', name='home'),
    # url(r'^demo/', include('demo.foo.urls')),

    # Uncomment the admin/doc line below to enable admin documentation:
    # url(r'^admin/doc/', include('django.contrib.admindocs.urls')),

    # Uncomment the next line to enable the admin:
    url(r'^admin/', include(admin.site.urls)),

    url(r'^$', HomeView.as_view(), name='home'),
    # Access
    url(r'^access/class/$', AccessView.as_view(), name='new_access_class'),
    url(r'^access/function/$', access_function_based_view, name='new_access_function'),
    url(r'^access/decorator/$', access_decorated_view, name='new_access_decorator'),
    url(r'^access/exception/$', AccessExceptionView.as_view(), name='new_access_exception'),
    url(r'^access/args/(\d+)/$', AccessView.as_view(), kwargs={'arg1': 1, 'arg2': True, 'arg3': 'test'}, name='new_access_args'),
    url(r'^access/last/', LastAccessView.as_view(), name='last_access'),
    # ModelAction
    url(r'^modelaction/create/$', CreateModelActionView.as_view(), name='create_modelaction'),
    url(r'^modelaction/update/$', UpdateModelActionView.as_view(), name='update_modelaction'),
    url(r'^modelaction/delete/$', DeleteModelActionView.as_view(), name='delete_modelaction'),
    url(r'^modelaction/last/$', LastModelActionView.as_view(), name='last_modelaction'),
    # Ebury Audit URLs
    url(r'^audit/', include('audit.urls'))
)

if DEBUG:
    urlpatterns += static(STATIC_URL, document_root=STATIC_ROOT)



from __future__ import unicode_literals

from functools import wraps
import datetime

from django.shortcuts import render_to_response
from django.utils import timezone
from django.views.generic import TemplateView, View, DetailView
from django.views.generic.base import TemplateResponseMixin

from demo.models import Test
from audit_tools.audit.models import Access, ModelAction
from audit_tools.audit.decorators import DisableAudit


def test_decorator(func):
    @wraps(func)
    def inner(*args, **kwargs):
        return func(*args, **kwargs)
    return inner


class HomeView(TemplateView):
    template_name = 'home.html'


class AccessView(TemplateView):
    template_name = 'access.html'


class AccessExceptionView(TemplateView):
    template_name = 'access.html'

    def get(self, request, *args, **kwargs):
        raise RuntimeError('Intended exception')


def access_function_based_view(request):
    return render_to_response('access.html', {})


@test_decorator
def access_decorated_view(request):
    return render_to_response('access.html', {})


class LastAccessView(DetailView):
    template_name = 'last_access.html'
    context_object_name = 'access'

    def get_object(self, queryset=None):
        try:
            return Access.objects.order_by('-time__request')[0]
        except:
            return None


class LastModelActionView(DetailView):
    template_name = 'last_modelaction.html'
    context_object_name = 'modelaction'

    def get_object(self, queryset=None):
        try:
            return ModelAction.objects.order_by('-timestamp')[0]
        except:
            return None


class CreateModelActionView(TemplateResponseMixin, View):
    template_name = 'create_modelaction.html'

    def create(self, *args, **kwargs):
        self.object = Test(name='test', force_time=datetime.datetime.now().time())
        self.object.save()
        return self.object

    def get(self, request, *args, **kwargs):
        self.create(*args, **kwargs)
        self.request = request
        return self.render_to_response({})

    def post(self, request, *args, **kwargs):
        self.create(*args, **kwargs)
        self.request = request
        return self.render_to_response({})


class UpdateModelActionView(TemplateResponseMixin, View):
    template_name = 'update_modelaction.html'

    def update(self, *args, **kwargs):
        self.object = Test.objects.all().order_by('-pk')[0]
        self.object.name = 'TestUpdated'
        self.object.time = timezone.now()
        self.object.save()
        return self.object

    def get(self, request, *args, **kwargs):
        self.update(*args, **kwargs)
        self.request = request
        return self.render_to_response({})

    def post(self, request, *args, **kwargs):
        self.update(*args, **kwargs)
        self.request = request
        return self.render_to_response({})


class DeleteModelActionView(TemplateResponseMixin, View):
    template_name = 'delete_modelaction.html'

    def delete(self, *args, **kwargs):
        self.object = Test.objects.all().order_by('-pk')[0]
        self.object.delete()
        return self.object

    def get(self, request, *args, **kwargs):
        self.delete(*args, **kwargs)
        self.request = request
        return self.render_to_response({})

    def post(self, request, *args, **kwargs):
        self.delete(*args, **kwargs)
        self.request = request
        return self.render_to_response({})




from __future__ import unicode_literals

import os


PROJECT_PATH = os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))
APP_PATH = os.path.abspath(os.path.dirname(__file__))

DEBUG = True
TEMPLATE_DEBUG = DEBUG

ADMINS = (
    # ('Your Name', 'your_email@example.com'),
)

MANAGERS = ADMINS

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',  # Add 'postgresql_psycopg2', 'mysql', 'sqlite3' or 'oracle'.
        'NAME': 'EbAudit.db',                    # Or path to database file if using sqlite3.
        'USER': '',                      # Not used with sqlite3.
        'PASSWORD': '',                  # Not used with sqlite3.
        'HOST': '',                      # Set to empty string for localhost. Not used with sqlite3.
        'PORT': '',                      # Set to empty string for default. Not used with sqlite3.
    },

    'audit': {
        'ENGINE': '',
    }
}

# Hosts/domain names that are valid for this site; required if DEBUG is False
# See https://docs.djangoproject.com/en/1.4/ref/settings/#allowed-hosts
ALLOWED_HOSTS = ['*']

# Local time zone for this installation. Choices can be found here:
# http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
# although not all choices may be available on all operating systems.
# In a Windows environment this must be set to your system time zone.
TIME_ZONE = 'Europe/Madrid'

# Language code for this installation. All choices can be found here:
# http://www.i18nguy.com/unicode/language-identifiers.html
LANGUAGE_CODE = 'en-us'

SITE_ID = 1

# If you set this to False, Django will make some optimizations so as not
# to load the internationalization machinery.
USE_I18N = True

# If you set this to False, Django will not format dates, numbers and
# calendars according to the current locale.
USE_L10N = True

# If you set this to False, Django will not use timezone-aware datetimes.
USE_TZ = True

# Absolute filesystem path to the directory that will hold user-uploaded files.
# Example: "/home/media/media.lawrence.com/media/"
MEDIA_ROOT = PROJECT_PATH + '/media/'

# URL that handles the media served from MEDIA_ROOT. Make sure to use a
# trailing slash.
# Examples: "http://media.lawrence.com/media/", "http://example.com/media/"
MEDIA_URL = '/media/'

# Absolute path to the directory static files should be collected to.
# Don't put anything in this directory yourself; store your static files
# in apps' "static/" subdirectories and in STATICFILES_DIRS.
# Example: "/home/media/media.lawrence.com/static/"
STATIC_ROOT = PROJECT_PATH + '/static/'

# URL prefix for static files.
# Example: "http://media.lawrence.com/static/"
STATIC_URL = '/static/'

# Additional locations of static files
STATICFILES_DIRS = (
    # Put strings here, like "/home/html/static" or "C:/www/django/static".
    # Always use forward slashes, even on Windows.
    # Don't forget to use absolute paths, not relative paths.
    APP_PATH + '/static/',
)

# List of finder classes that know how to find static files in
# various locations.
STATICFILES_FINDERS = (
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
    # 'django.contrib.staticfiles.finders.DefaultStorageFinder',
)

# Make this unique, and don't share it with anybody.
SECRET_KEY = '3+&amp;*6eq%(gs1heqnu!fpb%&amp;#16_^3x#s_nh04^7dxa8tgb%meu'

# List of callables that know how to import templates from various sources.
TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.Loader',
    'django.template.loaders.app_directories.Loader',
    # 'django.template.loaders.eggs.Loader',
)

TEMPLATE_CONTEXT_PROCESSORS = (
    'django.contrib.auth.context_processors.auth',
    "django.core.context_processors.debug",
    "django.core.context_processors.i18n",
    "django.core.context_processors.media",
    #"django.core.context_processors.request",
)

MIDDLEWARE_CLASSES = (
    'ebury_interlink.middleware.InterlinkMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    # Uncomment the next line for simple clickjacking protection:
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'audit_tools.audit.middleware.AuditMiddleware',
)

ROOT_URLCONF = 'demo.urls'

# Python dotted path to the WSGI application used by Django's runserver.
WSGI_APPLICATION = 'demo.wsgi.application'

TEMPLATE_DIRS = (
    # Put strings here, like "/home/html/django_templates" or "C:/www/django/templates".
    # Always use forward slashes, even on Windows.
    # Don't forget to use absolute paths, not relative paths.
    APP_PATH + '/templates/',
)

INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    # Uncomment the next line to enable the admin:
    'django.contrib.admin',
    # Uncomment the next line to enable admin documentation:
    # 'django.contrib.admindocs',
    'demo',
    'audit_tools',
    'ebury_interlink',
)

# A sample logging configuration. The only tangible logging
# performed by this configuration is to send an email to
# the site admins on every HTTP 500 error when DEBUG=False.
# See http://docs.djangoproject.com/en/dev/topics/logging for
# more details on how to customize your logging configuration.
# LOGGING = {
#     'version': 1,
#     'disable_existing_loggers': False,
#     'handlers': {
#         'mail_admins': {
#             'level': 'ERROR',
#             'class': 'django.utils.log.AdminEmailHandler'
#         }
#     },
#     'loggers': {
#         'django.request': {
#             'handlers': ['mail_admins'],
#             'level': 'ERROR',
#             'propagate': True,
#         },
#     }
# }

# EbAudit settings
AUDIT_ACTIVATE = True
AUDIT_RUN_ASYNC = False
AUDIT_LOGGING = True
AUDIT_LOGGING_PATH = PROJECT_PATH
AUDIT_CELERY_QUEUE = 'audit'
AUDIT_LOGGED_MODELS = (
    'demo.models.Test',
)
AUDIT_BLACKLIST = {
    'demo': (
        r'^(?!(/access/|/modelaction/)).*$',
    )
}
AUDIT_CUSTOM_PROVIDER = {}
AUDIT_DB_ALIAS = 'audit'
AUDIT_DB_CONNECTION = {
    'HOST': '127.0.0.1',
    'NAME': 'audit',
    'USER': os.environ.get('DB_AUDIT_USER'),
    'PASSWORD': os.environ.get('DB_AUDIT_PASSWORD'),
}



import datetime

from django.db import models


class Test(models.Model):
    name = models.CharField(max_length=128)
    time = models.DateTimeField(default=datetime.datetime.now())
    force_time = models.TimeField()


# -*- coding: utf-8 -*-
from __future__ import unicode_literals

"""django-audit-tools"""
__version__ = '0.4.0'
__license__ = 'GNU GPL v2'

__author__ = 'José Antonio Perdiguero López'
__email__ = 'perdy.hh@gmail.com'

__url__ = 'https://github.com/PeRDy/django-audit-tools'
__description__ = 'Django application that provides a set of tools for auditing requests and models and improve logging'

default_app_config = 'audit_tools.apps.AuditToolsApp'



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import sys

from setuptools import setup
from setuptools.command.test import test as TestCommand
from pip.req import parse_requirements
from pip.download import PipSession

import audit_tools

requirements_file = os.path.join(os.path.dirname(__file__), 'requirements.txt')
requires = [str(r.req) for r in parse_requirements(requirements_file, session=PipSession())]


class Tox(TestCommand):
    user_options = [('tox-args=', 'a', "Arguments to pass to tox")]

    def initialize_options(self):
        TestCommand.initialize_options(self)
        self.tox_args = ''

    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        import tox
        import shlex
        errno = tox.cmdline(args=shlex.split(self.tox_args))
        sys.exit(errno)


setup(
    name='django-audit-tools',
    version=audit_tools.__version__,
    description=audit_tools.__description__,
    long_description='\n'.join([open('README.rst').read(), open('CHANGELOG').read()]),
    author=audit_tools.__author__,
    author_email=audit_tools.__email__,
    maintainer=audit_tools.__author__,
    maintainer_email=audit_tools.__email__,
    url=audit_tools.__url__,
    download_url=audit_tools.__url__,
    packages=[
        'audit_tools',
    ],
    include_package_data=True,
    install_requires=requires,
    license=open('LICENSE').read(),
    zip_safe=False,
    keywords='python, django, database, requests, audit, logging',
    classifiers=[
        # Framework
        'Framework :: Django',
        # Environment
        'Environment :: Web Environment',
        # Intended Audience:
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'Intended Audience :: System Administrators',
        # License
        'License :: OSI Approved :: GNU General Public License v2 or later (GPLv2+)',
        # Natural Language
        'Natural Language :: English',
        # Operating System
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX',
        # Programming Language
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        # Topic
        'Topic :: Software Development',
        'Topic :: Software Development :: Bug Tracking',
        'Topic :: System :: Logging',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    test_suite='tests',
    tests_require=['tox'],
    cmdclass={'test': Tox},
)



# -*- coding: utf-8 -*-
"""
Audit Tools app.
"""
from django.apps import AppConfig
from audit_tools.audit.signals import register_models


class AuditToolsApp(AppConfig):
    name = 'audit_tools'
    verbose_name = 'Audit Tools'

    def ready(self):
        # Register all models listed in LOGGED_MODELS
        register_models()
